summaryrefslogtreecommitdiff
path: root/poezio/core
diff options
context:
space:
mode:
Diffstat (limited to 'poezio/core')
-rw-r--r--poezio/core/core.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/poezio/core/core.py b/poezio/core/core.py
index 3f435aa3..f9d30cfe 100644
--- a/poezio/core/core.py
+++ b/poezio/core/core.py
@@ -77,7 +77,7 @@ class Core(object):
self.bookmarks = BookmarkList()
self.debug = False
self.remote_fifo = None
# a unique buffer used to store global informations
# that are displayed in almost all tabs, in an
# information window.
self.information_buffer = TextBuffer()
@@ -926,7 +926,7 @@ class Core(object):
def get_error_message(self, stanza, deprecated=False):
"""
Takes a stanza of the form <message type='error'><error/></message>
- and return a well formed string containing the error informations
+ and return a well formed string containing error information
"""
sender = stanza['from']
msg = stanza['error']['type']
@@ -77,7 +77,7 @@ class Core(object):
self.debug = False
self.remote_fifo = None
- # a unique buffer used to store global informations
+ # a unique buffer used to store global information
# that are displayed in almost all tabs, in an
# information window.